@@ -17,7 +17,9 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "abstractcontextmanageritem.moc"
+#include "abstractcontextmanageritem.h"
+
+#include "abstractcontextmanageritem.h"
 
 // Local
 #include <lib/contextmanager.h>
