@@ -19,13 +19,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "abstractimageoperation.moc"
+#include "abstractimageoperation.h"
 
 // Qt
+#include <QUrl>
 
 // KDE
 #include <KJob>
-#include <KUrl>
 
 // Local
 #include "document/documentfactory.h"
@@ -58,7 +58,7 @@ private:
 struct AbstractImageOperationPrivate
 {
     QString mText;
-    KUrl mUrl;
+    QUrl mUrl;
 };
 
 AbstractImageOperation::AbstractImageOperation()
