@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include <thumbnailgenerator.moc>
+#include "thumbnailgenerator.h"
 
 // Local
 #include "imageutils.h"
@@ -28,8 +28,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "exiv2imageloader.h"
 
 // KDE
-#include <KDebug>
+#include <QDebug>
+#ifdef KDCRAW_FOUND
 #include <libkdcraw/kdcraw.h>
+#endif
 
 // Qt
 #include <QImageReader>
@@ -43,7 +45,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) //qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -72,6 +74,7 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
     QBuffer buffer;
     int previewRatio = 1;
 
+#ifdef KDCRAW_FOUND
     // raw images deserve special treatment
     if (KDcrawIface::KDcraw::rawFilesList().contains(QString(formatHint))) {
         // use KDCraw to extract the preview
@@ -83,7 +86,7 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
             // if the emebedded preview loading failed or gets just a small image, load
             // half preview instead. That's slower...
             if (!KDcrawIface::KDcraw::loadHalfPreview(data, pixPath)) {
-                kWarning() << "unable to get preview for " << pixPath.toUtf8().constData();
+                qWarning() << "unable to get preview for " << pixPath.toUtf8().constData();
                 return false;
             }
             previewRatio = 2;
@@ -91,7 +94,7 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
 
         // And we need JpegContent too because of EXIF (orientation!).
         if (!content.loadFromData(data)) {
-            kWarning() << "unable to load preview for " << pixPath.toUtf8().constData();
+            qWarning() << "unable to load preview for " << pixPath.toUtf8().constData();
             return false;
         }
 
@@ -100,6 +103,9 @@ bool ThumbnailContext::load(const QString &pixPath, int pixelSize)
         reader.setDevice(&buffer);
         reader.setFormat(formatHint);
     } else {
+#else
+    {
+#endif
         if (!reader.canRead()) {
             reader.setDecideFormatFromContent(true);
             // Set filename again, otherwise QImageReader won't restart from scratch
@@ -280,7 +286,7 @@ void ThumbnailGenerator::run()
                     cacheThumbnail();
                 }
             } else {
-                kWarning() << "Could not generate thumbnail for file" << mOriginalUri;
+                qWarning() << "Could not generate thumbnail for file" << mOriginalUri;
             }
             mPixPath.clear(); // done, ready for next
         }
@@ -300,13 +306,13 @@ void ThumbnailGenerator::run()
 
 void ThumbnailGenerator::cacheThumbnail()
 {
-    mImage.setText("Thumb::URI"          , 0, mOriginalUri);
-    mImage.setText("Thumb::MTime"        , 0, QString::number(mOriginalTime));
-    mImage.setText("Thumb::Size"         , 0, QString::number(mOriginalFileSize));
-    mImage.setText("Thumb::Mimetype"     , 0, mOriginalMimeType);
-    mImage.setText("Thumb::Image::Width" , 0, QString::number(mOriginalWidth));
-    mImage.setText("Thumb::Image::Height", 0, QString::number(mOriginalHeight));
-    mImage.setText("Software"            , 0, "Gwenview");
+    mImage.setText("Thumb::URI"          , mOriginalUri);
+    mImage.setText("Thumb::MTime"        , QString::number(mOriginalTime));
+    mImage.setText("Thumb::Size"         , QString::number(mOriginalFileSize));
+    mImage.setText("Thumb::Mimetype"     , mOriginalMimeType);
+    mImage.setText("Thumb::Image::Width" , QString::number(mOriginalWidth));
+    mImage.setText("Thumb::Image::Height", QString::number(mOriginalHeight));
+    mImage.setText("Software"            , QStringLiteral("Gwenview"));
 
     emit thumbnailReadyToBeCached(mThumbnailPath, mImage);
 }
